@@ -245,7 +245,7 @@ class xtable:
 
     def wrap(self) :
         self.__superwrap = True
-        return __repr__()
+        return self.__repr__()
 
     def csv(self):
         import io
